@@ -6,6 +6,7 @@ import (
 	"crypto/x509"
 	"flag"
 	"fmt"
+
 	"io/ioutil"
 	"net/http"
 	"net/url"
@@ -17,6 +18,7 @@ import (
 
 	"github.com/openshift/console/pkg/auth"
 	"github.com/openshift/console/pkg/bridge"
+	"github.com/openshift/console/pkg/crypto"
 	"github.com/openshift/console/pkg/proxy"
 	"github.com/openshift/console/pkg/server"
 	"github.com/openshift/console/pkg/serverconfig"
@@ -30,11 +32,18 @@ const (
 	k8sInClusterCA          = "/var/run/secrets/kubernetes.io/serviceaccount/ca.crt"
 	k8sInClusterBearerToken = "/var/run/secrets/kubernetes.io/serviceaccount/token"
 
-	// Well-known location of Prometheus service for OpenShift. This is only accessible in-cluster.
+	// Well-known location of the cluster monitoring (not user workload monitoring) Prometheus service for OpenShift.
+	// This is only accessible in-cluster. This is used for non-tenant global (alerting) rules requests.
 	openshiftPrometheusHost = "prometheus-k8s.openshift-monitoring.svc:9091"
 
-	// The tenancy service port (9092) performs RBAC checks for namespace-specific queries.
-	openshiftPrometheusTenancyHost = "prometheus-k8s.openshift-monitoring.svc:9092"
+	// Well-known location of the tenant aware Thanos service for OpenShift. This is only accessible in-cluster.
+	// Thanos proxies requests to both cluster monitoring and user workload monitoring prometheus instances.
+	openshiftThanosTenancyHost = "thanos-querier.openshift-monitoring.svc:9092"
+
+	// Well-known location of the Thanos service for OpenShift. This is only accessible in-cluster.
+	// This is used for non-tenant global query requests
+	// proxying to both cluster monitoring and user workload monitoring prometheus instances.
+	openshiftThanosHost = "thanos-querier.openshift-monitoring.svc:9091"
 
 	// Well-known location of Alert Manager service for OpenShift. This is only accessible in-cluster.
 	openshiftAlertManagerHost = "alertmanager-main.openshift-monitoring.svc:9094"
@@ -69,7 +78,9 @@ func main() {
 	fK8sModeOffClusterEndpoint := fs.String("k8s-mode-off-cluster-endpoint", "", "URL of the Kubernetes API server.")
 	fK8sModeOffClusterSkipVerifyTLS := fs.Bool("k8s-mode-off-cluster-skip-verify-tls", false, "DEV ONLY. When true, skip verification of certs presented by k8s API server.")
 	fK8sModeOffClusterPrometheus := fs.String("k8s-mode-off-cluster-prometheus", "", "DEV ONLY. URL of the cluster's Prometheus server.")
+	fK8sModeOffClusterThanos := fs.String("k8s-mode-off-cluster-thanos", "", "DEV ONLY. URL of the cluster's Prometheus server.")
 	fK8sModeOffClusterAlertmanager := fs.String("k8s-mode-off-cluster-alertmanager", "", "DEV ONLY. URL of the cluster's AlertManager server.")
+	fK8sModeOffClusterMetering := fs.String("k8s-mode-off-cluster-metering", "", "DEV ONLY. URL of the cluster's metering server.")
 
 	fK8sAuth := fs.String("k8s-auth", "service-account", "service-account | bearer-token | oidc | openshift")
 	fK8sAuthBearerToken := fs.String("k8s-auth-bearer-token", "", "Authorization token to send with proxied Kubernetes API requests.")
@@ -94,7 +105,6 @@ func main() {
 	fCustomLogoFile := fs.String("custom-logo-file", "", "Custom product image for console branding.")
 	fStatuspageID := fs.String("statuspage-id", "", "Unique ID assigned by statuspage.io page that provides status info.")
 	fDocumentationBaseURL := fs.String("documentation-base-url", "", "The base URL for documentation links.")
-	fGoogleTagManagerID := fs.String("google-tag-manager-id", "", "Google Tag Manager ID. External analytics are disabled if this is not set.")
 
 	fLoadTestFactor := fs.Int("load-test-factor", 0, "DEV ONLY. The factor used to multiply k8s API list responses for load testing purposes.")
 
@@ -146,18 +156,6 @@ func main() {
 		documentationBaseURL = bridge.ValidateFlagIsURL("documentation-base-url", *fDocumentationBaseURL)
 	}
 
-	offClusterPrometheusURL := &url.URL{}
-	if *fK8sModeOffClusterPrometheus != "" && *fK8sMode == "off-cluster" {
-		offClusterPrometheusURL = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-prometheus", *fK8sModeOffClusterPrometheus)
-		offClusterPrometheusURL.Path = "/api"
-	}
-
-	offClusterAlertManagerURL := &url.URL{}
-	if *fK8sModeOffClusterAlertmanager != "" && *fK8sMode == "off-cluster" {
-		offClusterAlertManagerURL = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-alertmanager", *fK8sModeOffClusterAlertmanager)
-		offClusterAlertManagerURL.Path = "/api"
-	}
-
 	branding := *fBranding
 	if branding == "origin" {
 		branding = "okd"
@@ -188,7 +186,6 @@ func main() {
 		CustomLogoFile:       *fCustomLogoFile,
 		StatuspageID:         *fStatuspageID,
 		DocumentationBaseURL: documentationBaseURL,
-		GoogleTagManagerID:   *fGoogleTagManagerID,
 		LoadTestFactor:       *fLoadTestFactor,
 	}
 
@@ -252,7 +249,10 @@ func main() {
 		if !rootCAs.AppendCertsFromPEM(k8sCertPEM) {
 			log.Fatalf("No CA found for the API server")
 		}
-		tlsConfig := &tls.Config{RootCAs: rootCAs}
+		tlsConfig := &tls.Config{
+			RootCAs:      rootCAs,
+			CipherSuites: crypto.DefaultCiphers(),
+		}
 
 		bearerToken, err := ioutil.ReadFile(k8sInClusterBearerToken)
 		if err != nil {
@@ -277,16 +277,24 @@ func main() {
 			if !serviceProxyRootCAs.AppendCertsFromPEM(serviceCertPEM) {
 				log.Fatalf("no CA found for Kubernetes services")
 			}
-			serviceProxyTLSConfig := &tls.Config{RootCAs: serviceProxyRootCAs}
+			serviceProxyTLSConfig := &tls.Config{
+				RootCAs:      serviceProxyRootCAs,
+				CipherSuites: crypto.DefaultCiphers(),
+			}
 			srv.PrometheusProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusHost, Path: "/api"},
 			}
-			srv.PrometheusTenancyProxyConfig = &proxy.Config{
+			srv.ThanosProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
-				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusTenancyHost, Path: "/api"},
+				Endpoint:        &url.URL{Scheme: "https", Host: openshiftThanosHost, Path: "/api"},
+			}
+			srv.ThanosTenancyProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        &url.URL{Scheme: "https", Host: openshiftThanosTenancyHost, Path: "/api"},
 			}
 			srv.AlertManagerProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
@@ -304,6 +312,7 @@ func main() {
 		k8sEndpoint = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-endpoint", *fK8sModeOffClusterEndpoint)
 		serviceProxyTLSConfig := &tls.Config{
 			InsecureSkipVerify: *fK8sModeOffClusterSkipVerifyTLS,
+			CipherSuites:       crypto.DefaultCiphers(),
 		}
 		srv.K8sProxyConfig = &proxy.Config{
 			TLSClientConfig: serviceProxyTLSConfig,
@@ -311,20 +320,32 @@ func main() {
 			Endpoint:        k8sEndpoint,
 		}
 
-		if offClusterPrometheusURL.String() != "" {
+		if *fK8sModeOffClusterPrometheus != "" {
+			offClusterPrometheusURL := bridge.ValidateFlagIsURL("k8s-mode-off-cluster-prometheus", *fK8sModeOffClusterPrometheus)
+			offClusterPrometheusURL.Path = "/api"
 			srv.PrometheusProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        offClusterPrometheusURL,
 			}
-			srv.PrometheusTenancyProxyConfig = &proxy.Config{
+
+			offClusterThanosURL := bridge.ValidateFlagIsURL("k8s-mode-off-cluster-thanos", *fK8sModeOffClusterThanos)
+			offClusterThanosURL.Path = "/api"
+			srv.ThanosTenancyProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
-				Endpoint:        offClusterPrometheusURL,
+				Endpoint:        offClusterThanosURL,
+			}
+			srv.ThanosProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        offClusterThanosURL,
 			}
 		}
 
-		if offClusterAlertManagerURL.String() != "" {
+		if *fK8sModeOffClusterAlertmanager != "" {
+			offClusterAlertManagerURL := bridge.ValidateFlagIsURL("k8s-mode-off-cluster-alertmanager", *fK8sModeOffClusterAlertmanager)
+			offClusterAlertManagerURL.Path = "/api"
 			srv.AlertManagerProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
@@ -332,6 +353,16 @@ func main() {
 			}
 		}
 
+		if *fK8sModeOffClusterMetering != "" {
+			offClusterMeteringURL := bridge.ValidateFlagIsURL("k8s-mode-off-cluster-metering", *fK8sModeOffClusterMetering)
+			offClusterMeteringURL.Path = "/api"
+			srv.MeteringProxyConfig = &proxy.Config{
+				TLSClientConfig: serviceProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        offClusterMeteringURL,
+			}
+		}
+
 	default:
 		bridge.FlagFatalf("k8s-mode", "must be one of: in-cluster, off-cluster")
 	}
