@@ -6,7 +6,7 @@ import * as crudView from '../views/crud.view';
 const BROWSER_TIMEOUT = 15000;
 
 describe('Create a test namespace', () => {
-  it(`creates test namespace ${testName} if necessary`, async() => {
+  it(`creates test namespace ${testName} if necessary`, async () => {
     // Use projects if OpenShift so non-admin users can run tests.
     const resource = browser.params.openshift === 'true' ? 'projects' : 'namespaces';
     await browser.get(`${appHost}/k8s/cluster/${resource}`);
@@ -15,9 +15,17 @@ describe('Create a test namespace', () => {
     if (!exists) {
       await crudView.createYAMLButton.click();
       await browser.wait(until.presenceOf($('.modal-body__field')));
-      await $$('.modal-body__field').get(0).$('input').sendKeys(testName);
-      await $$('.modal-body__field').get(1).$('input').sendKeys(`test-name=${testName}`);
-      await $('.modal-content').$('#confirm-action').click();
+      await $$('.modal-body__field')
+        .get(0)
+        .$('input')
+        .sendKeys(testName);
+      await $$('.modal-body__field')
+        .get(1)
+        .$('input')
+        .sendKeys(`test-name=${testName}`);
+      await $('.modal-content')
+        .$('#confirm-action')
+        .click();
       await browser.wait(until.urlContains(`/${testName}`), BROWSER_TIMEOUT);
     }
     expect(browser.getCurrentUrl()).toContain(appHost);
