@@ -3,9 +3,6 @@ export const CEPH_DEGRADED = 'health is degraded';
 export const CEPH_ERROR = 'health is in error state';
 export const CEPH_UNKNOWN = 'is not available';
 export const CEPH_STORAGE_NAMESPACE = 'openshift-storage';
-export const ONE_HR = '1 Hour';
-export const SIX_HR = '6 Hours';
-export const TWENTY_FOUR_HR = '24 Hours';
 export const PROJECTS = 'Projects';
 export const STORAGE_CLASSES = 'Storage Classes';
 export const PODS = 'Pods';
