@@ -31,13 +31,21 @@ namespace ExtensionProperties {
     /** Loader for the corresponding tab component. */
     loader: LazyLoader<OverviewDetailsResourcesTabProps>;
   }
+
+  export interface OverviewTabSection {
+    /** Name of key to be checked in prop items. */
+    key: string;
+
+    /** Loader for the corresponding tab component. */
+    loader: LazyLoader<OverviewDetailsResourcesTabProps>;
+  }
 }
 
 export interface OverviewCRD extends Extension<ExtensionProperties.OverviewCRD> {
   type: 'Overview/CRD';
 }
 
-export const isOverviewCRD = (e: Extension<any>): e is OverviewCRD => {
+export const isOverviewCRD = (e: Extension): e is OverviewCRD => {
   return e.type === 'Overview/CRD';
 };
 
@@ -45,6 +53,14 @@ export interface OverviewResourceTab extends Extension<ExtensionProperties.Overv
   type: 'Overview/Resource';
 }
 
-export const isOverviewResourceTab = (e: Extension<any>): e is OverviewResourceTab => {
+export const isOverviewResourceTab = (e: Extension): e is OverviewResourceTab => {
   return e.type === 'Overview/Resource';
 };
+
+export interface OverviewTabSection extends Extension<ExtensionProperties.OverviewTabSection> {
+  type: 'Overview/Section';
+}
+
+export const isOverviewTabSection = (e: Extension): e is OverviewTabSection => {
+  return e.type === 'Overview/Section';
+};
