@@ -1,8 +1,10 @@
 import * as React from 'react';
+import * as _ from 'lodash';
 import { Link } from 'react-router-dom';
 import { resourceObjPath } from '@console/internal/components/utils';
 import { K8sResourceKind, PodKind } from '@console/internal/module/k8s';
 import { PodStatus } from '@console/internal/components/pod';
+import { DaemonSetModel } from '@console/internal/models';
 import { PodControllerOverviewItem } from '../types';
 
 export const resourceStatus = (
@@ -10,6 +12,15 @@ export const resourceStatus = (
   current?: PodControllerOverviewItem,
   isRollingOut?: boolean,
 ) => {
+  if (obj.kind === DaemonSetModel.kind) {
+    return (
+      <OverviewItemReadiness
+        desired={_.get(obj, ['status', 'desiredNumberScheduled'], null)}
+        ready={_.get(obj, ['status', 'currentNumberScheduled'], null)}
+        resource={obj}
+      />
+    );
+  }
   return isRollingOut ? (
     <span className="text-muted">Rollout in progress...</span>
   ) : (
