@@ -1,6 +1,6 @@
 import * as React from 'react';
 import { shallow, ShallowWrapper } from 'enzyme';
-import TopologyDataController, { TopologyDataControllerProps } from '../TopologyDataController';
+import { TopologyDataControllerProps, TopologyDataController } from '../TopologyDataController';
 import { resources } from './topology-test-data';
 
 const TestInner = () => null;
@@ -10,6 +10,7 @@ describe('TopologyDataController', () => {
     namespace: 'test',
     resources,
     knative: false,
+    serviceBinding: false,
     cheURL: 'https://test-che.test-cluster.com',
     render: () => <TestInner />,
   };
@@ -17,7 +18,12 @@ describe('TopologyDataController', () => {
 
   beforeEach(() => {
     wrapper = shallow(
-      <TopologyDataController application={undefined} namespace="namespace" {...props} />,
+      <TopologyDataController
+        resourceList={[]}
+        application={undefined}
+        namespace="namespace"
+        {...props}
+      />,
     );
   });
 
