@@ -69,7 +69,7 @@ export interface Pipeline extends K8sResourceKind {
     params?: PipelineParam[];
     resources?: PipelineResource[];
     tasks: PipelineTask[];
-    serviceAccount?: string;
+    serviceAccountName?: string;
   };
 }
 
@@ -78,7 +78,6 @@ export interface PipelineRun extends K8sResourceKind {
     pipelineRef: { name: string };
     params?: PipelineRunParam[];
     resources?: PipelineResource[];
-    serviceAccount?: string;
     serviceAccountName?: string;
     // Odd status value that only appears in a single case - cancelling a pipeline
     status?: 'PipelineRunCancelled';
@@ -278,12 +277,14 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
         taskStatus[runStatus.Running]++;
       } else if (status === 'Failed') {
         taskStatus[runStatus.Failed]++;
+      } else if (status === 'Cancelled') {
+        taskStatus[runStatus.Cancelled]++;
       } else {
         taskStatus[runStatus.Pending]++;
       }
     });
-    taskStatus[runStatus.Failed] > 0
-      ? (taskStatus[runStatus.Cancelled] =
+    taskStatus[runStatus.Failed] > 0 || taskStatus[runStatus.Cancelled] > 0
+      ? (taskStatus[runStatus.Cancelled] +=
           totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks)
       : (taskStatus[runStatus.Pending] +=
           totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks);
