@@ -1,21 +1,17 @@
 import * as React from 'react';
 import { ListPage } from '@console/internal/components/factory';
 import { referenceForModel } from '@console/internal/module/k8s';
-import { TechPreviewBadge } from '@console/shared';
+import { getBadgeFromType } from '@console/shared';
 import { RouteModel } from '../../models';
 import RouteList from './RouteList';
 
-export interface RoutesPageProps {
-  namespace: string;
-}
-
-const RoutesPage: React.FC<RoutesPageProps> = ({ namespace }) => (
+const RoutesPage: React.FC<React.ComponentProps<typeof ListPage>> = (props) => (
   <ListPage
-    namespace={namespace}
+    {...props}
     canCreate={false}
     kind={referenceForModel(RouteModel)}
     ListComponent={RouteList}
-    badge={<TechPreviewBadge />}
+    badge={getBadgeFromType(RouteModel.badge)}
   />
 );
 
