@@ -49,3 +49,22 @@ export type VMConfig = {
   storageResources: StorageResource[];
   networkResources: NetworkResource[];
 };
+
+export type ProvisionConfig = {
+  provision: ProvisionOption;
+  networkResources: NetworkResource[];
+  storageResources: StorageResource[];
+};
+
+export type VMTemplateConfig = {
+  name: string;
+  namespace: string;
+  description: string;
+  provisionSource?: ProvisionOption;
+  operatingSystem?: string;
+  flavor?: string;
+  workloadProfile?: string;
+  cloudInit?: CloudInitConfig;
+  storageResources?: StorageResource[];
+  networkResources?: NetworkResource[];
+};
