@@ -1,7 +1,6 @@
 import { k8sPatch, resourceURL } from '@console/internal/module/k8s';
 import { getName, getNamespace } from '@console/shared';
 import { coFetch } from '@console/internal/co-fetch';
-import { analyticsSvc } from '@console/internal/module/analytics';
 import { getPxeBootPatch } from '../../patches/vm/vm-boot-patches';
 import { VirtualMachineModel } from '../../../models';
 import { VMKind } from '../../../types/vm';
@@ -27,10 +26,6 @@ const VMActionRequest = async (vm: VMKind, action: VMActionType) => {
   const response = await coFetch(url, { method });
   const text = await response.text();
 
-  if (!response.ok) {
-    analyticsSvc.error(`${text}: ${method} ${response.url}`);
-  }
-
   return text;
 };
 
