@@ -1,17 +1,18 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import {
-  DashboardCard,
-  DashboardCardBody,
-  DashboardCardHeader,
-  DashboardCardTitle,
-} from '@console/internal/components/dashboard/dashboard-card';
+import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
+import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
+import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
+import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardTitle';
+import { getName } from '@console/shared';
 import {
   DashboardItemProps,
   withDashboardResources,
-} from '@console/internal/components/dashboards-page/with-dashboard-resources';
+} from '@console/internal/components/dashboard/with-dashboard-resources';
 import { FirehoseResource } from '@console/internal/components/utils';
+import { StorageClassModel } from '@console/internal/models';
 import { referenceForModel, K8sResourceKind } from '@console/internal/module/k8s';
+import { PrometheusResponse } from '@console/internal/components/graphs';
 import { getMetric, getGaugeValue } from '../../utils';
 import { NooBaaObjectBucketClaimModel } from '../../models';
 import { BucketsItem, BucketsType } from './buckets-card-item';
@@ -34,6 +35,23 @@ const objectBucketClaimsResource: FirehoseResource = {
   prop: 'obc',
 };
 
+const storageClassResource: FirehoseResource = {
+  kind: StorageClassModel.kind,
+  isList: true,
+  prop: 'storageclass',
+};
+
+const getNoobaaStorageClasses = (storageClassesList) =>
+  storageClassesList.filter((sc) => _.endsWith(_.get(sc, 'provisioner'), 'noobaa.io/obc'));
+
+const getNoobaaObcCount = (obcList, noobaaStorageClasses) => {
+  const result = obcList.filter((o) => {
+    const storageClassName = _.get(o, 'spec.storageClassName');
+    return noobaaStorageClasses.some((sc) => getName(sc) === storageClassName);
+  });
+  return result.length;
+};
+
 const ObjectDashboardBucketsCard: React.FC<DashboardItemProps> = ({
   watchK8sResource,
   watchPrometheus,
@@ -44,62 +62,92 @@ const ObjectDashboardBucketsCard: React.FC<DashboardItemProps> = ({
 }) => {
   React.useEffect(() => {
     watchK8sResource(objectBucketClaimsResource);
+    watchK8sResource(storageClassResource);
     Object.keys(BucketsCardQueries).forEach((key) => watchPrometheus(BucketsCardQueries[key]));
     return () => {
       Object.keys(BucketsCardQueries).forEach((key) =>
         stopWatchPrometheusQuery(BucketsCardQueries[key]),
       );
       stopWatchK8sResource(objectBucketClaimsResource);
+      stopWatchK8sResource(storageClassResource);
     };
   }, [watchK8sResource, watchPrometheus, stopWatchK8sResource, stopWatchPrometheusQuery]);
 
-  const obCountResponse = prometheusResults.getIn([BucketsCardQueries.BUCKETS_COUNT, 'result']);
+  const obCountResponse = prometheusResults.getIn([
+    BucketsCardQueries.BUCKETS_COUNT,
+    'data',
+  ]) as PrometheusResponse;
+  const obCountResponseError = prometheusResults.getIn([
+    BucketsCardQueries.BUCKETS_COUNT,
+    'loadError',
+  ]);
   const obObjectsCountResponse = prometheusResults.getIn([
     BucketsCardQueries.BUCKET_OBJECTS_COUNT,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const obObjectsCountResponseError = prometheusResults.getIn([
+    BucketsCardQueries.BUCKET_OBJECTS_COUNT,
+    'loadError',
   ]);
   const unhealthyObResponse = prometheusResults.getIn([
     BucketsCardQueries.UNHEALTHY_BUCKETS,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const unhealthyObResponseError = prometheusResults.getIn([
+    BucketsCardQueries.UNHEALTHY_BUCKETS,
+    'loadError',
   ]);
   const obcCountResponse = prometheusResults.getIn([
     BucketsCardQueries.BUCKET_CLAIMS_COUNT,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const obcCountResponseError = prometheusResults.getIn([
+    BucketsCardQueries.BUCKET_CLAIMS_COUNT,
+    'loadError',
   ]);
   const obcObjectsCountsResponse = prometheusResults.getIn([
     BucketsCardQueries.BUCKET_CLAIMS_OBJECTS_COUNT,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const obcObjectsCountsResponseError = prometheusResults.getIn([
+    BucketsCardQueries.BUCKET_CLAIMS_OBJECTS_COUNT,
+    'loadError',
   ]);
   const unhealthyObcCountResponse = prometheusResults.getIn([
     BucketsCardQueries.UNHEALTHY_BUCKETS_CLAIMS,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const unhealthyObcCountResponseError = prometheusResults.getIn([
+    BucketsCardQueries.UNHEALTHY_BUCKETS_CLAIMS,
+    'loadError',
   ]);
   const bucketsLinksResponse = prometheusResults.getIn([
     BucketsCardQueries.BUCKETS_LINK_QUERY,
-    'result',
-  ]);
+    'data',
+  ]) as PrometheusResponse;
 
-  const obcData = _.get(resources.obc, 'data', null) as K8sResourceKind[];
+  const obcData = _.get(resources.obc, 'data', []) as K8sResourceKind[];
+  const storageClassesData = _.get(resources.storageclass, 'data', []) as K8sResourceKind[];
   const noobaaBucketsLink = getMetric(bucketsLinksResponse, 'buckets');
-  const obcCount = getGaugeValue(obcCountResponse);
+
+  const noobaaStorageClasses = getNoobaaStorageClasses(storageClassesData);
+  const k8sObc = getNoobaaObcCount(obcData, noobaaStorageClasses);
+  const prometheusObc = getGaugeValue(obcCountResponse);
   const unhealthyObcCount = getGaugeValue(unhealthyObcCountResponse);
 
-  let resultantUnhealthyObcCount: number = null;
-
-  if (obcCount && obcData && unhealthyObcCount)
-    resultantUnhealthyObcCount = obcData.length - Number(obcCount) + Number(unhealthyObcCount);
-
   const bucketProps: BucketsType = {
     bucketsCount: getGaugeValue(obCountResponse),
     objectsCount: getGaugeValue(obObjectsCountResponse),
     unhealthyCount: getGaugeValue(unhealthyObResponse),
     isLoading: !(obCountResponse && obObjectsCountResponse && unhealthyObResponse),
+    error: obCountResponseError || obObjectsCountResponseError || unhealthyObResponseError,
   };
   const bucketClaimProps: BucketsType = {
-    bucketsCount: obcCount,
+    bucketsCount: String(k8sObc),
     objectsCount: getGaugeValue(obcObjectsCountsResponse),
-    unhealthyCount: resultantUnhealthyObcCount,
+    unhealthyCount: k8sObc - Number(prometheusObc) + Number(unhealthyObcCount),
     isLoading: !(obcCountResponse && obcObjectsCountsResponse && unhealthyObcCountResponse),
+    error: obcCountResponseError || obcObjectsCountsResponseError || unhealthyObcCountResponseError,
   };
   return (
     <DashboardCard>
@@ -107,10 +155,8 @@ const ObjectDashboardBucketsCard: React.FC<DashboardItemProps> = ({
         <DashboardCardTitle>Buckets</DashboardCardTitle>
       </DashboardCardHeader>
       <DashboardCardBody>
-        <div className="co-dashboard-card__body--no-padding">
-          <BucketsItem title="ObjectBucket" {...bucketProps} link={noobaaBucketsLink} />
-          <BucketsItem title="ObjectBucketClaim" {...bucketClaimProps} link={noobaaBucketsLink} />
-        </div>
+        <BucketsItem title="Noobaa Bucket" {...bucketProps} link={noobaaBucketsLink} />
+        <BucketsItem title="Object Bucket Claim" {...bucketClaimProps} link={noobaaBucketsLink} />
       </DashboardCardBody>
     </DashboardCard>
   );
