@@ -516,10 +516,9 @@ export class SubscriptionUpdates extends React.Component<
                   _.get(obj.status, 'installplan') &&
                   this.props.installPlan ? (
                     <Link
-                      to={`/k8s/ns/${obj.metadata.namespace}/${InstallPlanModel.plural}/${_.get(
-                        obj.status,
-                        'installplan.name',
-                      )}`}
+                      to={`/k8s/ns/${obj.metadata.namespace}/${referenceForModel(
+                        InstallPlanModel,
+                      )}/${_.get(obj.status, 'installplan.name')}`}
                     >
                       <span>{installPlanPhase(this.props.installPlan)}</span>
                     </Link>
