@@ -2,7 +2,6 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
 import { connect } from 'react-redux';
-import { FieldLevelHelp } from 'patternfly-react';
 import { Alert, Button, ActionGroup, AlertActionCloseButton } from '@patternfly/react-core';
 import * as classNames from 'classnames';
 
@@ -13,6 +12,7 @@ import {
   ContainerDropdown,
   EnvFromPair,
   EnvType,
+  FieldLevelHelp,
   LoadingBox,
   LoadingInline,
   NameValueEditorPair,
@@ -25,8 +25,18 @@ import { ConfigMapModel, SecretModel } from '../models';
  * Set up an AsyncComponent to wrap the name-value-editor to allow on demand loading to reduce the
  * vendor footprint size.
  */
-const NameValueEditorComponent = (props) => <AsyncComponent loader={() => import('./utils/name-value-editor').then(c => c.NameValueEditor)} {...props} />;
-const EnvFromEditorComponent = (props) => <AsyncComponent loader={() => import('./utils/name-value-editor').then(c => c.EnvFromEditor)} {...props} />;
+const NameValueEditorComponent = (props) => (
+  <AsyncComponent
+    loader={() => import('./utils/name-value-editor').then((c) => c.NameValueEditor)}
+    {...props}
+  />
+);
+const EnvFromEditorComponent = (props) => (
+  <AsyncComponent
+    loader={() => import('./utils/name-value-editor').then((c) => c.EnvFromEditor)}
+    {...props}
+  />
+);
 
 /**
  * Set up initial value for the environment vars state. Use this in constructor or cancelChanges.
@@ -44,7 +54,7 @@ const EnvFromEditorComponent = (props) => <AsyncComponent loader={() => import('
  */
 const getPairsFromObject = (element = {}) => {
   const returnedPairs = {};
-  if ( _.isEmpty(element.env)) {
+  if (_.isEmpty(element.env)) {
     returnedPairs.env = [['', '', 0]];
   } else {
     returnedPairs.env = _.map(element.env, (leafNode, i) => {
@@ -56,8 +66,8 @@ const getPairsFromObject = (element = {}) => {
     });
   }
   if (_.isEmpty(element.envFrom)) {
-    const configMapSecretRef = {name: '', key: ''};
-    returnedPairs.envFrom = [['', {configMapSecretRef}, 0]];
+    const configMapSecretRef = { name: '', key: '' };
+    returnedPairs.envFrom = [['', { configMapSecretRef }, 0]];
   } else {
     returnedPairs.envFrom = _.map(element.envFrom, (leafNode, i) => {
       if (!_.has(leafNode, 'prefix')) {
@@ -89,10 +99,14 @@ const envVarsToArray = (initialPairObjects) => {
 };
 
 const getContainersObjectForDropdown = (containerArray) => {
-  return _.reduce(containerArray, (result, elem, order) => {
-    result[elem.name] = { ...elem, order };
-    return result;
-  }, {});
+  return _.reduce(
+    containerArray,
+    (result, elem, order) => {
+      result[elem.name] = { ...elem, order };
+      return result;
+    },
+    {},
+  );
 };
 
 class CurrentEnvVars {
@@ -166,29 +180,37 @@ class CurrentEnvVars {
       const containerEnvPatch = this.currentEnvVars.containers.map((finalPairsForContainer, i) => {
         const path = `/${envPath.join('/')}/${i}/env`;
         const value = this._envVarsToNameVal(finalPairsForContainer[EnvType.ENV]);
-        return {path, op, value};
+        return { path, op, value };
       });
 
-      const containerEnvFromPatch = this.currentEnvVars.containers.map((finalPairsForContainer, i) => {
-        const path = `/${envPath.join('/')}/${i}/envFrom`;
-        const value = this._envFromVarsToResourcePrefix(finalPairsForContainer[EnvType.ENV_FROM]);
-        return {path, op, value};
-      });
+      const containerEnvFromPatch = this.currentEnvVars.containers.map(
+        (finalPairsForContainer, i) => {
+          const path = `/${envPath.join('/')}/${i}/envFrom`;
+          const value = this._envFromVarsToResourcePrefix(finalPairsForContainer[EnvType.ENV_FROM]);
+          return { path, op, value };
+        },
+      );
 
       let patches = _.concat(containerEnvPatch, containerEnvFromPatch);
 
       if (this.hasInitContainers) {
-        const envPatchForIC = this.currentEnvVars.initContainers.map((finalPairsForContainer, i) => {
-          const path = `/${envPathForIC.join('/')}/${i}/env`;
-          const value = this._envVarsToNameVal(finalPairsForContainer[EnvType.ENV]);
-          return {path, op, value};
-        });
+        const envPatchForIC = this.currentEnvVars.initContainers.map(
+          (finalPairsForContainer, i) => {
+            const path = `/${envPathForIC.join('/')}/${i}/env`;
+            const value = this._envVarsToNameVal(finalPairsForContainer[EnvType.ENV]);
+            return { path, op, value };
+          },
+        );
 
-        const envFromPatchForIC = this.currentEnvVars.initContainers.map((finalPairsForContainer, i) => {
-          const path = `/${envPathForIC.join('/')}/${i}/envFrom`;
-          const value = this._envFromVarsToResourcePrefix(finalPairsForContainer[EnvType.ENV_FROM]);
-          return {path, op, value};
-        });
+        const envFromPatchForIC = this.currentEnvVars.initContainers.map(
+          (finalPairsForContainer, i) => {
+            const path = `/${envPathForIC.join('/')}/${i}/envFrom`;
+            const value = this._envFromVarsToResourcePrefix(
+              finalPairsForContainer[EnvType.ENV_FROM],
+            );
+            return { path, op, value };
+          },
+        );
 
         patches = _.concat(patches, envPatchForIC, envFromPatchForIC);
       }
@@ -198,7 +220,7 @@ class CurrentEnvVars {
       const op = 'add';
       const path = `/${envPath.join('/')}/env`;
       const value = this._envVarsToNameVal(finalPairsForContainer[EnvType.ENV]);
-      return {path, op, value};
+      return { path, op, value };
     });
   }
 
@@ -209,7 +231,9 @@ class CurrentEnvVars {
    * @public
    */
   dispatchNewEnvironmentVariables() {
-    return this.isCreate ? this._envVarsToNameVal(this.currentEnvVars.containers[0][EnvType.ENV]) : null;
+    return this.isCreate
+      ? this._envVarsToNameVal(this.currentEnvVars.containers[0][EnvType.ENV])
+      : null;
   }
 
   /**
@@ -221,14 +245,13 @@ class CurrentEnvVars {
    * @private
    */
   _envVarsToNameVal(finalEnvPairs) {
-    return _.filter(finalEnvPairs, finalEnvPair => finalEnvPair[NameValueEditorPair.Name])
-      .map(finalPairForContainer => {
+    return _.filter(finalEnvPairs, (finalEnvPair) => finalEnvPair[NameValueEditorPair.Name]).map(
+      (finalPairForContainer) => {
         const name = finalPairForContainer[NameValueEditorPair.Name];
         const value = finalPairForContainer[NameValueEditorPair.Value];
-        return _.isObject(value)
-          ? { name, valueFrom: value }
-          : { name, value };
-      });
+        return _.isObject(value) ? { name, valueFrom: value } : { name, value };
+      },
+    );
   }
 
   /**
@@ -240,26 +263,35 @@ class CurrentEnvVars {
    * @private
    */
   _envFromVarsToResourcePrefix(finalEnvPairs) {
-    return _.filter(finalEnvPairs, finalEnvPair => (!_.isEmpty(finalEnvPair[EnvFromPair.Resource]) && !finalEnvPair[EnvFromPair.Resource].configMapSecretRef))
-      .map(finalPairForContainer => {
-        return _.assign({'prefix': finalPairForContainer[EnvFromPair.Prefix]}, finalPairForContainer[EnvFromPair.Resource]);
-      });
+    return _.filter(
+      finalEnvPairs,
+      (finalEnvPair) =>
+        !_.isEmpty(finalEnvPair[EnvFromPair.Resource]) &&
+        !finalEnvPair[EnvFromPair.Resource].configMapSecretRef,
+    ).map((finalPairForContainer) => {
+      return _.assign(
+        { prefix: finalPairForContainer[EnvFromPair.Prefix] },
+        finalPairForContainer[EnvFromPair.Resource],
+      );
+    });
   }
 }
 
 /** @type {(state: any, props: {obj?: object, rawEnvData?: any, readOnly: boolean, envPath: any, onChange?: (env: any) => void, addConfigMapSecret?: boolean, useLoadingInline?: boolean}) => {model: K8sKind}} */
-const stateToProps = ({k8s, UI}, {obj}) => ({
-  model: k8s.getIn(['RESOURCES', 'models', referenceFor(obj)]) || k8s.getIn(['RESOURCES', 'models', obj.kind]),
+const stateToProps = ({ k8s, UI }, { obj }) => ({
+  model:
+    k8s.getIn(['RESOURCES', 'models', referenceFor(obj)]) ||
+    k8s.getIn(['RESOURCES', 'models', obj.kind]),
   impersonate: UI.get('impersonate'),
 });
 
 export const EnvironmentPage = connect(stateToProps)(
   class EnvironmentPage extends PromiseComponent {
-  /**
-   * Set initial state and decide which kind of env we are setting up
-   *
-   * @param props
-   */
+    /**
+     * Set initial state and decide which kind of env we are setting up
+     *
+     * @param props
+     */
     constructor(props) {
       super(props);
 
@@ -272,16 +304,18 @@ export const EnvironmentPage = connect(stateToProps)(
         currentEnvVars,
         success: null,
         containerIndex: 0,
-        containerType: currentEnvVars.isContainerArray || currentEnvVars.isCreate ? 'containers' : 'buildObject',
+        containerType:
+          currentEnvVars.isContainerArray || currentEnvVars.isCreate ? 'containers' : 'buildObject',
       };
     }
 
     componentDidMount() {
       this._checkEditAccess();
-      const {addConfigMapSecret, readOnly} = this.props;
+      const { addConfigMapSecret, readOnly } = this.props;
       if (!addConfigMapSecret || readOnly) {
-        const configMaps = {}, secrets = {};
-        this.setState({configMaps, secrets});
+        const configMaps = {},
+          secrets = {};
+        this.setState({ configMaps, secrets });
         return;
       }
       const envNamespace = _.get(this.props, 'obj.metadata.namespace');
@@ -290,7 +324,7 @@ export const EnvironmentPage = connect(stateToProps)(
         k8sGet(ConfigMapModel, null, envNamespace).catch((err) => {
           if (err.response.status !== 403) {
             const errorMessage = err.message || 'Could not load config maps.';
-            this.setState({errorMessage});
+            this.setState({ errorMessage });
           }
           return {
             configMaps: {},
@@ -299,14 +333,13 @@ export const EnvironmentPage = connect(stateToProps)(
         k8sGet(SecretModel, null, envNamespace).catch((err) => {
           if (err.response.status !== 403) {
             const errorMessage = err.message || 'Could not load secrets.';
-            this.setState({errorMessage});
+            this.setState({ errorMessage });
           }
           return {
             secrets: {},
           };
         }),
-      ])
-        .then((([configMaps, secrets]) => this.setState({configMaps, secrets})));
+      ]).then(([configMaps, secrets]) => this.setState({ configMaps, secrets }));
     }
 
     componentDidUpdate(prevProps) {
@@ -315,16 +348,18 @@ export const EnvironmentPage = connect(stateToProps)(
 
       if (!_.isEqual(rawEnvData, prevProps.rawEnvData)) {
         this.setState({
-          ...!dirty && { currentEnvVars: new CurrentEnvVars(rawEnvData) },
+          ...(!dirty && { currentEnvVars: new CurrentEnvVars(rawEnvData) }),
           stale: dirty,
         });
       }
 
-      if (_.get(prevProps.obj, 'metadata.uid') !== _.get(obj, 'metadata.uid') ||
-          _.get(prevProps.model, 'apiGroup') !== _.get(model, 'apiGroup') ||
-          _.get(prevProps.model, 'path') !== _.get(model, 'path') ||
-          prevProps.impersonate !== impersonate ||
-          prevProps.readOnly !== readOnly) {
+      if (
+        _.get(prevProps.obj, 'metadata.uid') !== _.get(obj, 'metadata.uid') ||
+        _.get(prevProps.model, 'apiGroup') !== _.get(model, 'apiGroup') ||
+        _.get(prevProps.model, 'path') !== _.get(model, 'path') ||
+        prevProps.impersonate !== impersonate ||
+        prevProps.readOnly !== readOnly
+      ) {
         this._checkEditAccess();
       }
     }
@@ -350,7 +385,9 @@ export const EnvironmentPage = connect(stateToProps)(
         name,
         namespace,
       };
-      checkAccess(resourceAttributes, impersonate).then(resp => this.setState({ allowed: resp.status.allowed }));
+      checkAccess(resourceAttributes, impersonate).then((resp) =>
+        this.setState({ allowed: resp.status.allowed }),
+      );
     }
 
     /**
@@ -359,8 +396,8 @@ export const EnvironmentPage = connect(stateToProps)(
      * @param i
      */
     _updateEnvVars(env, i = 0, type = EnvType.ENV) {
-      const {onChange} = this.props;
-      const {currentEnvVars, containerType} = this.state;
+      const { onChange } = this.props;
+      const { currentEnvVars, containerType } = this.state;
       const currentEnv = _.cloneDeep(currentEnvVars);
       currentEnv.setFormattedVars(containerType, i, type, env.nameValuePairs);
       this.setState({
@@ -376,7 +413,7 @@ export const EnvironmentPage = connect(stateToProps)(
      * @private
      */
     _reload() {
-      const {rawEnvData} = this.props;
+      const { rawEnvData } = this.props;
       this.setState({
         currentEnvVars: new CurrentEnvVars(rawEnvData),
         dirty: false,
@@ -388,14 +425,14 @@ export const EnvironmentPage = connect(stateToProps)(
 
     _selectContainer(containerName) {
       const { rawEnvData } = this.props;
-      let containerIndex = _.findIndex(rawEnvData.containers, {name: containerName});
+      let containerIndex = _.findIndex(rawEnvData.containers, { name: containerName });
       if (containerIndex !== -1) {
         return this.setState({
           containerIndex,
           containerType: 'containers',
         });
       }
-      containerIndex = _.findIndex(rawEnvData.initContainers, {name: containerName});
+      containerIndex = _.findIndex(rawEnvData.initContainers, { name: containerName });
       if (containerIndex !== -1) {
         return this.setState({
           containerIndex,
@@ -414,8 +451,8 @@ export const EnvironmentPage = connect(stateToProps)(
      * @param e
      */
     _saveChanges(e) {
-      const {envPath, obj, model} = this.props;
-      const {currentEnvVars} = this.state;
+      const { envPath, obj, model } = this.props;
+      const { currentEnvVars } = this.state;
 
       e.preventDefault();
 
@@ -434,11 +471,22 @@ export const EnvironmentPage = connect(stateToProps)(
 
     dismissSuccess = () => {
       this.setState({ success: null });
-    }
+    };
 
     render() {
-      const {errorMessage, success, inProgress, currentEnvVars, stale, configMaps, secrets, containerIndex, containerType, allowed} = this.state;
-      const {rawEnvData, obj, addConfigMapSecret, useLoadingInline} = this.props;
+      const {
+        errorMessage,
+        success,
+        inProgress,
+        currentEnvVars,
+        stale,
+        configMaps,
+        secrets,
+        containerIndex,
+        containerType,
+        allowed,
+      } = this.state;
+      const { rawEnvData, obj, addConfigMapSecret, useLoadingInline } = this.props;
       const readOnly = this.props.readOnly || !allowed;
 
       if (!configMaps || !currentEnvVars || !secrets) {
@@ -449,64 +497,159 @@ export const EnvironmentPage = connect(stateToProps)(
       }
 
       const envVar = currentEnvVars.getEnvVarByTypeAndIndex(containerType, containerIndex);
-      const containerDropdown = currentEnvVars.isContainerArray ? <ContainerDropdown
-        currentKey={rawEnvData[containerType][containerIndex].name}
-        containers={getContainersObjectForDropdown(rawEnvData.containers)}
-        initContainers={getContainersObjectForDropdown(rawEnvData.initContainers)}
-        onChange={this.selectContainer} /> : null;
+      const containerDropdown = currentEnvVars.isContainerArray ? (
+        <ContainerDropdown
+          currentKey={rawEnvData[containerType][containerIndex].name}
+          containers={getContainersObjectForDropdown(rawEnvData.containers)}
+          initContainers={getContainersObjectForDropdown(rawEnvData.initContainers)}
+          onChange={this.selectContainer}
+        />
+      ) : null;
 
-      const owners = _.get(obj.metadata, 'ownerReferences', [])
-        .map((o, i) => <ResourceLink key={i} kind={referenceForOwnerRef(o)} name={o.name} namespace={obj.metadata.namespace} title={o.uid} inline />);
-      const containerVars =
-        <React.Fragment>
-          { (readOnly && !_.isEmpty(owners)) &&
+      const owners = _.get(obj.metadata, 'ownerReferences', []).map((o, i) => (
+        <ResourceLink
+          key={i}
+          kind={referenceForOwnerRef(o)}
+          name={o.name}
+          namespace={obj.metadata.namespace}
+          title={o.uid}
+          inline
+        />
+      ));
+      const containerVars = (
+        <>
+          {readOnly && !_.isEmpty(owners) && (
             <div className="co-toolbar__group co-toolbar__group--left">
-              <Alert isInline className="co-alert col-md-11 col-xs-10" variant="info" title="Environment variables set from parent">
-                View environment for resource {owners.length > 1 ? <React.Fragment>owners: {owners}</React.Fragment> : owners}
+              <Alert
+                isInline
+                className="co-alert col-md-11 col-xs-10"
+                variant="info"
+                title="Environment variables set from parent"
+              >
+                View environment for resource {owners.length > 1 ? <>owners: {owners}</> : owners}
               </Alert>
             </div>
-          }
-          { currentEnvVars.isContainerArray && <div className="co-toolbar__group co-toolbar__group--left">
-            <div className="co-toolbar__item">{containerType === 'containers' ? 'Container:' : 'Init Container:'}</div>
-            <div className="co-toolbar__item">{containerDropdown}</div>
+          )}
+          {currentEnvVars.isContainerArray && (
+            <div className="co-toolbar__group co-toolbar__group--left">
+              <div className="co-toolbar__item">
+                {containerType === 'containers' ? 'Container:' : 'Init Container:'}
+              </div>
+              <div className="co-toolbar__item">{containerDropdown}</div>
+            </div>
+          )}
+          <div className={classNames({ 'co-m-pane__body-group': !currentEnvVars.isCreate })}>
+            {!currentEnvVars.isCreate && (
+              <h3 className="co-section-heading-tertiary">
+                Single values (env)
+                {!readOnly && (
+                  <FieldLevelHelp>
+                    Define environment variables as key-value pairs to store configuration settings.
+                    You can enter text or add values from a ConfigMap or Secret. Drag and drop
+                    environment variables to change the order in which they are run. A variable can
+                    reference any other variables that come before it in the list, for example{' '}
+                    <code>FULLDOMAIN = $(SUBDOMAIN).example.com</code>.
+                  </FieldLevelHelp>
+                )}
+              </h3>
+            )}
+            <NameValueEditorComponent
+              nameValueId={containerIndex}
+              nameValuePairs={envVar[EnvType.ENV]}
+              updateParentData={this.updateEnvVars}
+              addString="Add Value"
+              nameString="Name"
+              readOnly={readOnly}
+              allowSorting={true}
+              configMaps={configMaps}
+              secrets={secrets}
+              addConfigMapSecret={addConfigMapSecret}
+            />
           </div>
-          }
-          <div className={classNames({'co-m-pane__body-group': !currentEnvVars.isCreate})}>
-            { !currentEnvVars.isCreate && <h3 className="co-section-heading-tertiary">Single values (env)
-              {
-                !readOnly && <FieldLevelHelp content={
-                  <div>Define environment variables as key-value pairs to store configuration settings. You can enter text or add values from a ConfigMap or Secret. Drag and drop environment variables to change the order in which they are run. A variable can reference any other variables that come before it in the list, for example <code>FULLDOMAIN = $(SUBDOMAIN).example.com</code>.</div>} />
-              }
-            </h3>
-            }
-            <NameValueEditorComponent nameValueId={containerIndex} nameValuePairs={envVar[EnvType.ENV]} updateParentData={this.updateEnvVars} addString="Add Value" nameString="Name" readOnly={readOnly} allowSorting={true} configMaps={configMaps} secrets={secrets} addConfigMapSecret={addConfigMapSecret} />
-          </div>
-          { currentEnvVars.isContainerArray && <div className="co-m-pane__body-group environment-buttons">
-            <h3 className="co-section-heading-tertiary">All values from existing config maps or secrets (envFrom) {
-              !readOnly && <FieldLevelHelp content={
-                <div>Add new values by referencing an existing config map or secret. Drag and drop environment variables within this section to change the order in which they are run.<br /><strong>Note: </strong>If identical values exist in both lists, the single value in the list above will take precedence.</div>} />
-            }
-            </h3>
-            <EnvFromEditorComponent nameValueId={containerIndex} nameValuePairs={envVar[EnvType.ENV_FROM]} updateParentData={this.updateEnvVars} readOnly={readOnly} configMaps={configMaps} secrets={secrets} />
-          </div>}
-        </React.Fragment>;
+          {currentEnvVars.isContainerArray && (
+            <div className="co-m-pane__body-group environment-buttons">
+              <h3 className="co-section-heading-tertiary">
+                All values from existing config maps or secrets (envFrom)
+                {!readOnly && (
+                  <FieldLevelHelp>
+                    Add new values by referencing an existing config map or secret. Drag and drop
+                    environment variables within this section to change the order in which they are
+                    run.
+                    <br />
+                    <strong>Note: </strong>If identical values exist in both lists, the single value
+                    in the list above will take precedence.
+                  </FieldLevelHelp>
+                )}
+              </h3>
+              <EnvFromEditorComponent
+                nameValueId={containerIndex}
+                nameValuePairs={envVar[EnvType.ENV_FROM]}
+                updateParentData={this.updateEnvVars}
+                readOnly={readOnly}
+                configMaps={configMaps}
+                secrets={secrets}
+              />
+            </div>
+          )}
+        </>
+      );
 
-      return <div className={classNames({'co-m-pane__body': !currentEnvVars.isCreate})}>
-        {containerVars}
-        { !currentEnvVars.isCreate && <div className="co-m-pane__body-group">
-          <div className="pf-c-form environment-buttons">
-            {errorMessage && <Alert isInline className="co-alert" variant="danger" title={errorMessage} />}
-            {stale && <Alert isInline className="co-alert" variant="info" title="The information on this page is no longer current.">Click Reload to update and lose edits, or Save Changes to overwrite.</Alert>}
-            {success && <Alert isInline className="co-alert" variant="success" title={success} action={<AlertActionCloseButton onClose={this.dismissSuccess} />} />}
-            {!readOnly && <ActionGroup>
-              <Button isDisabled={inProgress} type="submit" variant="primary" onClick={this.saveChanges}>Save</Button>
-              <Button isDisabled={inProgress} type="button" variant="secondary" onClick={this.reload}>Reload</Button>
-            </ActionGroup>}
-          </div>
-        </div> }
-      </div>;
+      return (
+        <div className={classNames({ 'co-m-pane__body': !currentEnvVars.isCreate })}>
+          {containerVars}
+          {!currentEnvVars.isCreate && (
+            <div className="co-m-pane__body-group">
+              <div className="pf-c-form environment-buttons">
+                {errorMessage && (
+                  <Alert isInline className="co-alert" variant="danger" title={errorMessage} />
+                )}
+                {stale && (
+                  <Alert
+                    isInline
+                    className="co-alert"
+                    variant="info"
+                    title="The information on this page is no longer current."
+                  >
+                    Click Reload to update and lose edits, or Save Changes to overwrite.
+                  </Alert>
+                )}
+                {success && (
+                  <Alert
+                    isInline
+                    className="co-alert"
+                    variant="success"
+                    title={success}
+                    action={<AlertActionCloseButton onClose={this.dismissSuccess} />}
+                  />
+                )}
+                {!readOnly && (
+                  <ActionGroup>
+                    <Button
+                      isDisabled={inProgress}
+                      type="submit"
+                      variant="primary"
+                      onClick={this.saveChanges}
+                    >
+                      Save
+                    </Button>
+                    <Button
+                      isDisabled={inProgress}
+                      type="button"
+                      variant="secondary"
+                      onClick={this.reload}
+                    >
+                      Reload
+                    </Button>
+                  </ActionGroup>
+                )}
+              </div>
+            </div>
+          )}
+        </div>
+      );
     }
-  });
+  },
+);
 EnvironmentPage.propTypes = {
   obj: PropTypes.object,
   rawEnvData: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
