@@ -11,9 +11,9 @@ import store from '../../redux';
 import { ButtonBar } from '../utils/button-bar';
 import { history } from '../utils/router';
 
-export const createModal: CreateModal = getModalContainer => {
+export const createModal: CreateModal = (getModalContainer) => {
   const modalContainer = document.getElementById('modal-container');
-  const result = new Promise(resolve => {
+  const result = new Promise((resolve) => {
     const closeModal = (e?: React.SyntheticEvent) => {
       if (e && e.stopPropagation) {
         e.stopPropagation();
@@ -24,7 +24,7 @@ export const createModal: CreateModal = getModalContainer => {
     Modal.setAppElement(modalContainer);
     ReactDOM.render(getModalContainer(closeModal), modalContainer);
   });
-  return {result};
+  return { result };
 };
 
 export const createModalLauncher: CreateModalLauncher = (Component) => (props) => {
@@ -40,15 +40,20 @@ export const createModalLauncher: CreateModalLauncher = (Component) => (props) =
 
     return (
       <Provider store={store}>
-        <Router {...{history, basename: window.SERVER_FLAGS.basePath}}>
+        <Router {...{ history, basename: window.SERVER_FLAGS.basePath }}>
           <Modal
             isOpen={true}
             contentLabel="Modal"
             onRequestClose={_handleClose}
             className={classNames('modal-dialog', props.modalClassName)}
             overlayClassName="co-overlay"
-            shouldCloseOnOverlayClick={!props.blocking}>
-            <Component {..._.omit(props, 'blocking', 'modalClassName') as any} cancel={_handleCancel} close={_handleClose} />
+            shouldCloseOnOverlayClick={!props.blocking}
+          >
+            <Component
+              {..._.omit(props, 'blocking', 'modalClassName') as any}
+              cancel={_handleCancel}
+              close={_handleClose}
+            />
           </Modal>
         </Router>
       </Provider>
@@ -57,9 +62,16 @@ export const createModalLauncher: CreateModalLauncher = (Component) => (props) =
   return createModal(getModalContainer);
 };
 
-export const ModalTitle: React.SFC<ModalTitleProps> = ({children, className = 'modal-header'}) => <div className={className}><h4 className="modal-title">{children}</h4></div>;
+export const ModalTitle: React.SFC<ModalTitleProps> = ({
+  children,
+  className = 'modal-header',
+}) => (
+  <div className={className}>
+    <h4 className="modal-title">{children}</h4>
+  </div>
+);
 
-export const ModalBody: React.SFC<ModalBodyProps> = ({children}) => (
+export const ModalBody: React.SFC<ModalBodyProps> = ({ children }) => (
   <div className="modal-body">
     <div className="modal-body-content">
       <div className="modal-body-inner-shadow-covers">{children}</div>
@@ -67,32 +79,67 @@ export const ModalBody: React.SFC<ModalBodyProps> = ({children}) => (
   </div>
 );
 
-
-export const ModalFooter: React.SFC<ModalFooterProps> = ({message, errorMessage, inProgress, children}) => {
-  return <ButtonBar className="modal-footer" errorMessage={errorMessage} infoMessage={message} inProgress={inProgress}>
-    {children}
-  </ButtonBar>;
+export const ModalFooter: React.SFC<ModalFooterProps> = ({
+  message,
+  errorMessage,
+  inProgress,
+  children,
+}) => {
+  return (
+    <ButtonBar
+      className="modal-footer"
+      errorMessage={errorMessage}
+      infoMessage={message}
+      inProgress={inProgress}
+    >
+      {children}
+    </ButtonBar>
+  );
 };
 
-export const ModalSubmitFooter: React.SFC<ModalSubmitFooterProps> = ({message, errorMessage, inProgress, cancel, submitText, cancelText, submitDisabled, submitDanger}) => {
-  const onCancelClick = e => {
+export const ModalSubmitFooter: React.SFC<ModalSubmitFooterProps> = ({
+  message,
+  errorMessage,
+  inProgress,
+  cancel,
+  submitText,
+  cancelText,
+  submitDisabled,
+  submitDanger,
+}) => {
+  const onCancelClick = (e) => {
     e.stopPropagation();
     cancel(e);
   };
 
-  return <ModalFooter inProgress={inProgress} errorMessage={errorMessage} message={message}>
-    <ActionGroup className="pf-c-form pf-c-form__actions--right pf-c-form__group--no-top-margin">
-      <Button type="button" variant="secondary" data-test-id="modal-cancel-action" onClick={onCancelClick}>{cancelText || 'Cancel'}</Button>
-      {submitDanger
-        ? <Button type="submit" variant="danger" isDisabled={submitDisabled} id="confirm-action">{submitText}</Button>
-        : <Button type="submit" variant="primary" isDisabled={submitDisabled} id="confirm-action">{submitText}</Button>}
-    </ActionGroup>
-  </ModalFooter>;
+  return (
+    <ModalFooter inProgress={inProgress} errorMessage={errorMessage} message={message}>
+      <ActionGroup className="pf-c-form pf-c-form__actions--right pf-c-form__group--no-top-margin">
+        <Button
+          type="button"
+          variant="secondary"
+          data-test-id="modal-cancel-action"
+          onClick={onCancelClick}
+        >
+          {cancelText || 'Cancel'}
+        </Button>
+        {submitDanger ? (
+          <Button type="submit" variant="danger" isDisabled={submitDisabled} id="confirm-action">
+            {submitText}
+          </Button>
+        ) : (
+          <Button type="submit" variant="primary" isDisabled={submitDisabled} id="confirm-action">
+            {submitText}
+          </Button>
+        )}
+      </ActionGroup>
+    </ModalFooter>
+  );
 };
 
 export type GetModalContainer = (onClose: (e?: React.SyntheticEvent) => void) => React.ReactElement;
 
-type CreateModal = (getModalContainer: GetModalContainer) => {result: Promise<any>};
+type CreateModal = (getModalContainer: GetModalContainer) => { result: Promise<any> };
 
 export type CreateModalLauncherProps = {
   blocking?: boolean;
@@ -129,5 +176,6 @@ export type ModalSubmitFooterProps = {
   submitDanger?: boolean;
 };
 
-export type CreateModalLauncher = <P extends ModalComponentProps>(C: React.ComponentType<P>) =>
-  (props: P & CreateModalLauncherProps) => {result: Promise<{}>};
+export type CreateModalLauncher = <P extends ModalComponentProps>(
+  C: React.ComponentType<P>,
+) => (props: P & CreateModalLauncherProps) => { result: Promise<{}> };
