@@ -3,9 +3,9 @@ import * as _ from 'lodash-es';
 import { PrometheusResponse, DataPoint } from '.';
 import { Humanize } from '../utils';
 
-export const getRangeVectorStats: GetStats = response => {
+export const getRangeVectorStats: GetStats = (response) => {
   const values = _.get(response, 'data.result[0].values');
-  return _.map(values, value => ({
+  return _.map(values, (value) => ({
     x: new Date(value[0] * 1000),
     y: parseFloat(value[1]),
   }));
@@ -13,7 +13,7 @@ export const getRangeVectorStats: GetStats = response => {
 
 export const getInstantVectorStats: GetStats = (response, metric, humanize) => {
   const results = _.get(response, 'data.result', []);
-  return results.map(r => {
+  return results.map((r) => {
     const y = parseFloat(_.get(r, 'value[1]'));
     return {
       label: humanize ? humanize(y).string : null,
@@ -26,4 +26,4 @@ export const getInstantVectorStats: GetStats = (response, metric, humanize) => {
 
 export type GetStats = {
   (response: PrometheusResponse, metric?: string, humanize?: Humanize): DataPoint[];
-}
+};
