@@ -7,7 +7,13 @@ import * as classNames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
 
 import { Dropdown, ResourceIcon } from './utils';
-import { K8sKind, K8sResourceKindReference, referenceForModel, apiVersionForReference, kindForReference } from '../module/k8s';
+import {
+  K8sKind,
+  K8sResourceKindReference,
+  referenceForModel,
+  apiVersionForReference,
+  kindForReference,
+} from '../module/k8s';
 
 // Blacklist known duplicate resources.
 const blacklistGroups = ImmutableSet([
@@ -37,25 +43,37 @@ const blacklistResources = ImmutableSet([
   'extensions/v1beta1.ReplicationControllerDummy',
 ]);
 
-const DropdownItem: React.SFC<DropdownItemProps> = ({model, showGroup}) => <React.Fragment>
-  <span className="co-resource-item">
-    <span className="co-resource-icon--fixed-width">
-      <ResourceIcon kind={referenceForModel(model)} />
+const DropdownItem: React.SFC<DropdownItemProps> = ({ model, showGroup }) => (
+  <>
+    <span className="co-resource-item">
+      <span className="co-resource-icon--fixed-width">
+        <ResourceIcon kind={referenceForModel(model)} />
+      </span>
+      <span className="co-resource-item__resource-name">
+        {model.kind}
+        {showGroup && (
+          <>
+            &nbsp;
+            <div className="co-resource-item__resource-api text-muted co-truncate show co-nowrap small">
+              {model.apiGroup || 'core'}/{model.apiVersion}
+            </div>
+          </>
+        )}
+      </span>
     </span>
-    <span className="co-resource-item__resource-name">
-      {model.kind}
-      {showGroup && <React.Fragment>&nbsp;<div className="co-resource-item__resource-api text-muted co-truncate show co-nowrap small">{model.apiGroup || 'core'}/{model.apiVersion}</div></React.Fragment>}
-    </span>
-  </span>
-</React.Fragment>;
+  </>
+);
 
-const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = props => {
+const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = (props) => {
   const { selected, onChange, allModels, showAll, className, preferredVersions } = props;
 
   const resources = allModels
-    .filter(({apiGroup, apiVersion, kind, verbs}) => {
+    .filter(({ apiGroup, apiVersion, kind, verbs }) => {
       // Remove blacklisted items.
-      if (blacklistGroups.has(apiGroup) || blacklistResources.has(`${apiGroup}/${apiVersion}.${kind}`)) {
+      if (
+        blacklistGroups.has(apiGroup) ||
+        blacklistResources.has(`${apiGroup}/${apiVersion}.${kind}`)
+      ) {
         return false;
       }
 
@@ -65,35 +83,44 @@ const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = props => {
       }
 
       // Only show preferred version for resources in the same API group.
-      const preferred = (m: K8sKind) => preferredVersions.some(v => v.groupVersion === apiVersionForReference(referenceForModel(m)));
-      const sameGroupKind = (m: K8sKind) => m.kind === kind && m.apiGroup === apiGroup && m.apiVersion !== apiVersion;
+      const preferred = (m: K8sKind) =>
+        preferredVersions.some(
+          (v) => v.groupVersion === apiVersionForReference(referenceForModel(m)),
+        );
+      const sameGroupKind = (m: K8sKind) =>
+        m.kind === kind && m.apiGroup === apiGroup && m.apiVersion !== apiVersion;
 
-      return !allModels.find(m => sameGroupKind(m) && preferred(m));
+      return !allModels.find((m) => sameGroupKind(m) && preferred(m));
     })
     .toOrderedMap()
-    .sortBy(({kind, apiGroup}) => `${kind} ${apiGroup}`);
+    .sortBy(({ kind, apiGroup }) => `${kind} ${apiGroup}`);
 
   // Track duplicate names so we know when to show the group.
-  const kinds = resources.groupBy(m => m.kind);
-  const isDup = kind => kinds.get(kind).size > 1;
+  const kinds = resources.groupBy((m) => m.kind);
+  const isDup = (kind) => kinds.get(kind).size > 1;
 
   // Create dropdown items for each resource.
-  const items = resources.map((model) => <DropdownItem key={referenceForModel(model)} model={model} showGroup={isDup(model.kind)} />) as OrderedMap<string, JSX.Element>;
+  const items = resources.map((model) => (
+    <DropdownItem key={referenceForModel(model)} model={model} showGroup={isDup(model.kind)} />
+  )) as OrderedMap<string, JSX.Element>;
 
   // Add an "All" item to the top if `showAll`.
   const allItems = (showAll
-    ? OrderedMap({all: <React.Fragment>
-      <span className="co-resource-item">
-        <span className="co-resource-icon--fixed-width">
-          <ResourceIcon kind="All" />
-        </span>
-        <span className="co-resource-item__resource-name">All Types</span>
-      </span>
-      {/* <ResourceIcon kind="All" /> */}
-    </React.Fragment>}).concat(items)
+    ? OrderedMap({
+        all: (
+          <>
+            <span className="co-resource-item">
+              <span className="co-resource-icon--fixed-width">
+                <ResourceIcon kind="All" />
+              </span>
+              <span className="co-resource-item__resource-name">All Types</span>
+            </span>
+            {/* <ResourceIcon kind="All" /> */}
+          </>
+        ),
+      }).concat(items)
     : items
-    )
-    .toJS() as {[s: string]: JSX.Element};
+  ).toJS() as { [s: string]: JSX.Element };
 
   const selectedKey = allItems[selected] ? selected : kindForReference(selected);
   const autocompleteFilter = (text, item) => {
@@ -105,23 +132,28 @@ const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = props => {
     return fuzzy(_.toLower(text), _.toLower(model.kind));
   };
 
-  return <Dropdown
-    menuClassName="dropdown-menu--text-wrap"
-    className={classNames('co-type-selector', className)}
-    items={allItems}
-    title={allItems[selectedKey]}
-    onChange={onChange}
-    autocompleteFilter={autocompleteFilter}
-    autocompletePlaceholder="Select Resource"
-    selectedKey={selectedKey} />;
+  return (
+    <Dropdown
+      menuClassName="dropdown-menu--text-wrap"
+      className={classNames('co-type-selector', className)}
+      items={allItems}
+      title={allItems[selectedKey]}
+      onChange={onChange}
+      autocompleteFilter={autocompleteFilter}
+      autocompletePlaceholder="Select Resource"
+      selectedKey={selectedKey}
+    />
+  );
 };
 
-const resourceListDropdownStateToProps = ({k8s}) => ({
+const resourceListDropdownStateToProps = ({ k8s }) => ({
   allModels: k8s.getIn(['RESOURCES', 'models']),
   preferredVersions: k8s.getIn(['RESOURCES', 'preferredVersions']),
 });
 
-export const ResourceListDropdown = connect(resourceListDropdownStateToProps)(ResourceListDropdown_);
+export const ResourceListDropdown = connect(resourceListDropdownStateToProps)(
+  ResourceListDropdown_,
+);
 
 ResourceListDropdown.propTypes = {
   onChange: PropTypes.func.isRequired,
@@ -136,7 +168,7 @@ export type ResourceListDropdownProps = {
   selected: K8sResourceKindReference;
   onChange: Function;
   allModels: ImmutableMap<K8sResourceKindReference, K8sKind>;
-  preferredVersions: {groupVersion: string, version: string}[];
+  preferredVersions: { groupVersion: string; version: string }[];
   className?: string;
   id?: string;
   showAll?: boolean;
