@@ -9,19 +9,31 @@ export const BuildHooks: React.SFC<BuildHooksProps> = ({ resource }) => {
   const postCommitCommand = _.get(resource, 'spec.postCommit.command');
   const postCommitScript = _.get(resource, 'spec.postCommit.script');
 
-  return (!_.isEmpty(postCommitCommand) || !_.isEmpty(postCommitArgs) || postCommitScript)
-    ? <div className="co-m-pane__body">
+  return !_.isEmpty(postCommitCommand) || !_.isEmpty(postCommitArgs) || postCommitScript ? (
+    <div className="co-m-pane__body">
       <SectionHeading text="Post-Commit Hooks" />
       <dl className="co-m-pane__details">
         {!_.isEmpty(postCommitCommand) && <dt>Command</dt>}
-        {!_.isEmpty(postCommitCommand) && <dd><code>{postCommitCommand.join(' ')}</code></dd>}
+        {!_.isEmpty(postCommitCommand) && (
+          <dd>
+            <code>{postCommitCommand.join(' ')}</code>
+          </dd>
+        )}
         {postCommitScript && <dt>Script</dt>}
-        {postCommitScript && <dd><code>{postCommitScript}</code></dd>}
+        {postCommitScript && (
+          <dd>
+            <code>{postCommitScript}</code>
+          </dd>
+        )}
         {!_.isEmpty(postCommitArgs) && <dt>Args</dt>}
-        {!_.isEmpty(postCommitArgs) && <dd><code>{postCommitArgs.join(' ')}</code></dd>}
+        {!_.isEmpty(postCommitArgs) && (
+          <dd>
+            <code>{postCommitArgs.join(' ')}</code>
+          </dd>
+        )}
       </dl>
     </div>
-    : null;
+  ) : null;
 };
 
 export type BuildHooksProps = {
